summaryrefslogtreecommitdiffstats
path: root/templates/annotated/menuapp1.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:03:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:03:49 -0600
commit387a27b62f25387e42a850739ced151d64a2e760 (patch)
treebbba39b506feb102175f10aa296b201a5a4557f5 /templates/annotated/menuapp1.py
parent3d1fa8562bf693237a1a76918b4487cca3e2e356 (diff)
downloadpytde-387a27b62f25387e42a850739ced151d64a2e760.tar.gz
pytde-387a27b62f25387e42a850739ced151d64a2e760.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'templates/annotated/menuapp1.py')
-rw-r--r--templates/annotated/menuapp1.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/templates/annotated/menuapp1.py b/templates/annotated/menuapp1.py
index faa8662..93b2a90 100644
--- a/templates/annotated/menuapp1.py
+++ b/templates/annotated/menuapp1.py
@@ -45,7 +45,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n, KStdAccel, KIcon, KIconLoader
+from tdecore import TDEApplication, TDECmdLineArgs, TDEAboutData, i18n, KStdAccel, KIcon, KIconLoader
from tdeui import KMainWindow, KMessageBox
TOOLBAR_NEW = 1
@@ -136,7 +136,7 @@ class MainWin (KMainWindow):
# Let KDE generate a nifty help menu
# The KAboutData/TDECmdLineArgs data from the main part of the program
# will be used to generate the About dialog
helpMenu = self.helpMenu ("")
@@ -253,8 +253,8 @@ class MainWin (KMainWindow):
description = "A basic application template"
version = "1.0"
-aboutData = KAboutData ("", "",\
- version, description, KAboutData.License_GPL,\
+aboutData = TDEAboutData ("", "",\
+ version, description, TDEAboutData.License_GPL,\
"(C) 2003 whoever the author is")
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
@@ -136,7 +136,7 @@ class MainWin (KMainWindow):
# Let KDE generate a nifty help menu
- # The KAboutData/TDECmdLineArgs data from the main part of the program
+ # The TDEAboutData/TDECmdLineArgs data from the main part of the program
# will be used to generate the About dialog
helpMenu = self.helpMenu ("")